..
    This file is part of Invenio.
    Copyright (C) 2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _documentation:

Documentation
=============

.. toctree::
    :maxdepth: 2

    requirements
    main-concepts/index
    bundles/index
